@@ -5,7 +5,7 @@ import traceback
 from PyQt5.QtCore import QDir, Qt, pyqtSlot, QTimer
 from PyQt5.QtGui import QIcon, QCloseEvent, QKeySequence
 from PyQt5.QtWidgets import QMainWindow, QUndoGroup, QActionGroup, QHeaderView, QAction, QFileDialog, \
-    QMessageBox, QApplication
+    QMessageBox, QApplication, qApp
 
 from urh import constants, version
 from urh.controller.dialogs.CSVImportDialog import CSVImportDialog
@@ -82,6 +82,9 @@ class MainController(QMainWindow):
         self.cancel_action.setIcon(QIcon.fromTheme("dialog-cancel"))
         self.addAction(self.cancel_action)
 
+        self.ui.actionAuto_detect_new_signals.setChecked(constants.SETTINGS.value("auto_detect_new_signals",
+                                                                                  True, bool))
+
         self.participant_legend_model = ParticipantLegendListModel(self.project_manager.participants)
         self.ui.listViewParticipants.setModel(self.participant_legend_model)
 
@@ -179,6 +182,7 @@ class MainController(QMainWindow):
         self.ui.actionSniff_protocol.triggered.connect(self.show_proto_sniff_dialog)
         self.ui.actionAbout_Qt.triggered.connect(QApplication.instance().aboutQt)
         self.ui.actionSamples_from_csv.triggered.connect(self.on_import_samples_from_csv_action_triggered)
+        self.ui.actionAuto_detect_new_signals.triggered.connect(self.on_auto_detect_new_signals_action_triggered)
 
         self.ui.btnFileTreeGoUp.clicked.connect(self.on_btn_file_tree_go_up_clicked)
         self.ui.fileTree.directory_open_wanted.connect(self.project_manager.set_project_folder)
@@ -204,6 +208,7 @@ class MainController(QMainWindow):
             self.on_show_field_types_config_action_triggered)
 
         self.compare_frame_controller.load_protocol_clicked.connect(self.on_compare_frame_controller_load_protocol_clicked)
+        self.compare_frame_controller.ui.listViewParticipants.doubleClicked.connect(self.on_project_settings_action_triggered)
 
         self.ui.lnEdtTreeFilter.textChanged.connect(self.on_file_tree_filter_text_changed)
 
@@ -253,6 +258,7 @@ class MainController(QMainWindow):
         proto = self.compare_frame_controller.add_protocol_from_file(filename)
         if proto:
             self.__add_empty_frame_for_filename(proto, filename)
+        self.ui.tabWidget.setCurrentWidget(self.ui.tab_protocol)
 
     def add_fuzz_profile(self, filename):
         self.ui.tabWidget.setCurrentIndex(2)
@@ -272,7 +278,7 @@ class MainController(QMainWindow):
         sig_name = os.path.splitext(os.path.basename(filename))[0]
 
         # Use default sample rate for signal
-        # Sample rate will be overriden in case of a project later
+        # Sample rate will be overridden in case of a project later
         if enforce_sample_rate is not None:
             sample_rate = enforce_sample_rate
         else:
@@ -292,8 +298,11 @@ class MainController(QMainWindow):
         signal.blockSignals(True)
         has_entry = self.project_manager.read_project_file_for_signal(signal)
 
-        if not has_entry and not signal.changed:
+        if self.ui.actionAuto_detect_new_signals.isChecked() and not has_entry and not signal.changed:
+            sig_frame.ui.stackedWidget.setCurrentWidget(sig_frame.ui.pageLoading)
+            qApp.processEvents()
             signal.auto_detect(detect_modulation=True, detect_noise=False)
+            sig_frame.ui.stackedWidget.setCurrentWidget(sig_frame.ui.pageSignal)
 
         signal.blockSignals(False)
 
@@ -343,7 +352,7 @@ class MainController(QMainWindow):
             self.set_frame_numbers()
             self.refresh_main_menu()
         except Exception as e:
-            Errors.generic_error(self.tr("Failed to close"), str(e), traceback.format_exc())
+            Errors.exception(e)
             self.unsetCursor()
 
     def add_files(self, filepaths, group_id=0, enforce_sample_rate=None):
@@ -551,7 +560,7 @@ class MainController(QMainWindow):
                 self.add_files(FileOperator.uncompress_archives([action.data()], QDir.tempPath()))
                 self.unsetCursor()
         except Exception as e:
-            Errors.generic_error(self.tr("Failed to open"), str(e), traceback.format_exc())
+            Errors.exception(e)
             self.unsetCursor()
 
     @pyqtSlot()
@@ -649,6 +658,9 @@ class MainController(QMainWindow):
                 self.generator_tab_controller.ui.tabWidget.widget(i).layout().setContentsMargins(0, 7 + h - th, 0, 0)
             # Modulators may got changed from Simulator Dialog
             self.generator_tab_controller.refresh_modulators()
+            # Signals may got reordered in analysis
+            self.generator_tab_controller.tree_model.update()
+            self.generator_tab_controller.ui.treeProtocols.expandAll()
 
     @pyqtSlot()
     def on_show_record_dialog_action_triggered(self):
@@ -771,7 +783,7 @@ class MainController(QMainWindow):
                     self.add_files(file_names)
                     self.unsetCursor()
             except Exception as e:
-                Errors.generic_error(self.tr("Failed to open"), str(e), traceback.format_exc())
+                Errors.exception(e)
                 self.unsetCursor()
 
     @pyqtSlot()
@@ -863,6 +875,10 @@ class MainController(QMainWindow):
     def on_import_samples_from_csv_action_triggered(self):
         self.__import_csv(file_name="")
 
+    @pyqtSlot(bool)
+    def on_auto_detect_new_signals_action_triggered(self, checked: bool):
+        constants.SETTINGS.setValue("auto_detect_new_signals", bool(checked))
+
     def __import_csv(self, file_name, group_id=0):
         def on_data_imported(complex_file, sample_rate):
             sample_rate = None if sample_rate == 0 else sample_rate
