@@ -50,7 +50,7 @@ class ProtocolLabelDialog(QDialog):
 
         self.ui.tblViewProtoLabels.resizeColumnsToContents()
         self.setWindowFlags(Qt.Window)
-        self.setWindowTitle(self.tr("Edit Protocol Labels from message type %s") % message.message_type.name)
+        self.setWindowTitle(self.tr("Edit Protocol Labels From Message Type %s") % message.message_type.name)
 
         self.configure_special_config_tabs()
         self.ui.splitter.setSizes([self.height() / 2, self.height() / 2])
@@ -62,6 +62,7 @@ class ProtocolLabelDialog(QDialog):
 
         self.ui.cbProtoView.setCurrentIndex(viewtype)
         self.setAttribute(Qt.WA_DeleteOnClose)
+        self.setWindowFlags(Qt.Window)
 
         try:
             self.restoreGeometry(constants.SETTINGS.value("{}/geometry".format(self.__class__.__name__)))
