@@ -107,6 +107,10 @@ class VirtualDevice(QObject):
                     from urh.dev.native.BladeRF import BladeRF
                     self.__dev = BladeRF(center_freq=freq, sample_rate=sample_rate, bandwidth=bandwidth, gain=gain,
                                          resume_on_full_receive_buffer=resume_on_full_receive_buffer)
+                elif name == "plutosdr":
+                    from urh.dev.native.PlutoSDR import PlutoSDR
+                    self.__dev = PlutoSDR(center_freq=freq, sample_rate=sample_rate, bandwidth=bandwidth, gain=gain,
+                                         resume_on_full_receive_buffer=resume_on_full_receive_buffer)
                 elif name.startswith("airspy"):
                     from urh.dev.native.AirSpy import AirSpy
                     self.__dev = AirSpy(center_freq=freq, sample_rate=sample_rate, bandwidth=bandwidth,
@@ -154,6 +158,13 @@ class VirtualDevice(QObject):
         if mode == Mode.spectrum:
             self.__dev.is_in_spectrum_mode = True
 
+    @property
+    def data_type(self):
+        if self.backend == Backends.native:
+            return self.__dev.DATA_TYPE
+        else:
+            return np.float32
+
     @property
     def has_multi_device_support(self):
         return hasattr(self.__dev, "has_multi_device_support") and self.__dev.has_multi_device_support
@@ -389,6 +400,18 @@ class VirtualDevice(QObject):
         else:
             raise ValueError("Unsupported Backend")
 
+    @property
+    def subdevice(self):
+        if hasattr(self.__dev, "subdevice"):
+            return self.__dev.subdevice
+        else:
+            return None
+
+    @subdevice.setter
+    def subdevice(self, value: str):
+        if hasattr(self.__dev, "subdevice"):
+            self.__dev.subdevice = value
+
     @property
     def ip(self):
         if self.backend == Backends.grc:
@@ -556,7 +579,7 @@ class VirtualDevice(QObject):
             if self.backend == Backends.grc:
                 return self.__dev.x, self.__dev.y
             elif self.backend == Backends.native or self.backend == Backends.network:
-                w = np.abs(np.fft.fft(self.__dev.receive_buffer))
+                w = np.abs(np.fft.fft(self.__dev.receive_buffer.as_complex64()))
                 freqs = np.fft.fftfreq(len(w), 1 / self.sample_rate)
                 idx = np.argsort(freqs)
                 return freqs[idx].astype(np.float32), w[idx].astype(np.float32)
